## Product details

Brutus Broth started with our beloved pup, Brutus, who got a tastier meal and nutritional benefits from Grandma's bone broth. As a dog food topper, the bone broth for dogs made his dry food more easily digestible and improved his joint health. We created Brutus Broth to share these benefits with other dogs!
100% human-grade ingredients that contain no artificial colors, flavors or preservatives.  Gluten-free, Soy-free, dairy-free, wheat-free and non-GMO
Nourishing all natural nutrients that contribute to your dog's overall health and Promotes Healthy Skin, Teeth, and Nails. With added glucosamine and chondroitin support hip and joint health, and turmeric which helps with inflammation.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
Specifications

Pet food flavor
Beef
Meat type
Beef
Pet food form
Broth
Product net content parent
32 Ounces
More details
Indications

Animal Health Concern
Hip & Joint Care Digestive Care Coat Care Appetite Stimulation Immune Support Skin Care Bone Health Muscle Support Aging
Directions

Instructions
Shake well: **Ready to Serve **Do Not Microwave in this Carton **Twisting Cap Will Open Package
Feeding Instructions
Our serving suggestion is per meal based on two meals a day. We recommend serving approximately 1/4 cup of broth per 25 pounds of body weight per meal. Adjust per your pet's needs. Refer to our feeding guide to determine how much Brutus Broth to serve your dog.
Ingredients

Ingredients
Beef Bone Broth, Natural Flavor (contains Torula Yeast), Organic Potato Starch, Glucosamine Hydrochloride, Sweet Potato Powder, Carrot powder, Salt, Yeast Extract, Organic Beef Flavor, Chondroitin Sulfate, Turmeric.

Active Ingredient Name
Beef Bone Broth, Natural Flavor, Glucosamine Hydrochloride, Carrot Powder, Salt, Yeast Extract, Sweet Potato Powder, Beef Flavor, Chondroitin Sulfate, Canola Oil, Turmeric.
